Create a custom projection based on the planning region
make_custom_projection.RdCreate a custom projection based on the planning region
Argumentos
- boundary
sfobject of the boundary of the planning region. Should match iso3 country code.- output_path
An optional output path for the created file.
- iso3_column
A string of the name of where iso3 information can be found in a dataset.
- iso3
The iso3 country code (character) of the country of interest.
Exemplos
boundary <- make_boundary(
boundary_in = boundary_dat,
iso3 = "NPL",
iso3_column = "iso3cd"
)
#> [2026-04-03 09:18:20] Creating boundary for planning region...
#> [2026-04-03 09:18:20] Creating custom Mollweide projection centred on planning region...
wkt <- make_custom_projection(boundary = boundary, iso3 = "NPL")
#> [2026-04-03 09:18:20] Creating custom Mollweide projection centred on planning region...